﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Data.Odbc;

namespace BarCodeScanner
{
    public partial class Login : Form
    {
        string connstr; //connection string
        OdbcConnection conn; 
        string passwordString; //store login password
        OdbcCommand com;
        OdbcDataAdapter da;
        DataSet ds;
        string dsn="";
        string pwd="";
        string driver="";
        string database="";
        int loginMode = 1; //the default login mode is student mode
        Boolean databaseChanged = false; //every time database chosen changed, you have to test connection
        string errorMessage;

        public Login()
        {
            InitializeComponent();
        }
       
        private void btnTest_Click(object sender, EventArgs e)//test connection 
        {
            try
            {
                database = cbxDatabase.Text.Trim();
                passwordString = pwd;
                //the connection string for ODBC
                connstr = "Driver={"+driver+"};Dsn="+dsn+";UID=root;PWD="+pwd+";Database="+database;
                conn = new OdbcConnection(connstr);
                conn.Open();
                MessageBox.Show("Connection Successful","Test Result",MessageBoxButtons.OK,MessageBoxIcon.Information);
                conn.Close();
                btnOK.Enabled = true;
                btnNew.Enabled = true;
                btnOK.Focus();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK,MessageBoxIcon.Error);
                textChanged();
                if (conn.State == ConnectionState.Open)//close connection
                { 
                    conn.Close();
                }
            }
        }
        
        private void btnOK_Click(object sender, EventArgs e)//call the barcodeCounter.cs( LOGIN button )
        {
            this.Hide();
            //send this form, connection string, login password and login mode as params
            BarcodeCounter bc = new BarcodeCounter(this, connstr, passwordString,loginMode);
            bc.Show();
        }

        private void btnNew_Click(object sender, EventArgs e)//call createTable.cs
        {
            this.Hide();
            CreateTables ct = new CreateTables(this, connstr);//send this form and connection string as params
            ct.Show();
        }

        private void textDsn_TextChanged(object sender, EventArgs e)
        {
            textChanged();
        }

        private void textPwd_TextChanged(object sender, EventArgs e)
        {
            textChanged();
        }

        private void textDatabase_TextChanged(object sender, EventArgs e)
        {
            textChanged();
        }

        private void cbxDriver_SelectedIndexChanged(object sender, EventArgs e)
        {
            textChanged();
        }

        private void cbxDatabase_DropDown(object sender, EventArgs e)//add database list as combobox items
        {
            if (databaseChanged)
            {
                try
                {
                    dsn = textDsn.Text.Trim();
                    pwd = textPwd.Text.Trim();
                    driver = cbxDriver.Text.Trim();

                    connstr = "Driver={" + driver + "};Dsn=" + dsn + ";UID=root;PWD=" + pwd;
                    conn = new OdbcConnection(connstr);
                    com = new OdbcCommand("SHOW Databases;", conn);
                    da = new OdbcDataAdapter(com);
                    ds = new DataSet();
                    da.Fill(ds);
                    cbxDatabase.Items.Clear();
                    for (int i = 0; i < ds.Tables[0].Rows.Count; i++)
                    {
                        cbxDatabase.Items.Add(ds.Tables[0].Rows[i][0].ToString());
                    }
                }
                catch (Exception ex)
                {
                    errorMessage = ex.Message;
                }
            }
        }

        private void labelSwitchMode_Click(object sender, EventArgs e)//change login mode
        {
            if (loginMode / 2 == 0)
            {
                labelSwitchMode.Text = "Switch to Student Mode";
                groupBox1.Text = "LOGIN (Professor Mode)";
                loginMode = 2;
            }
            else
            {
                labelSwitchMode.Text = "Switch to Professor Mode";
                groupBox1.Text = "LOGIN (Student Mode)";
                loginMode = 1;
            }
        }

        private void cbxDatabase_TextChanged(object sender, EventArgs e)//after choose the database, enable btn Test connection
        {
            if (cbxDatabase.Text == "")
            {
                btnTest.Enabled = false;
                textChanged();
            }
            else
            {
                btnTest.Enabled = true;
            }
        }

        private void textChanged()//any text changed, you should text connection again before login
        {
            btnOK.Enabled = false;
            btnNew.Enabled = false;
            databaseChanged = true;
        }

        private void btnExit_Click(object sender, EventArgs e)
        {
            this.Close();
        }

    }


}
